@@ -858,6 +858,7 @@ extern struct subr_tab_ {
   subr_ D_unintern;
   subr_ D_export;
   subr_ D_unexport;
+  subr_ D_reexport;
   subr_ D_import;
   subr_ D_shadowing_import;
   subr_ D_shadow;
@@ -865,7 +866,6 @@ extern struct subr_tab_ {
   subr_ D_unuse_package;
   subr_ D_make_package;
   subr_ D_pin_package;
-  subr_ D_in_package;
   subr_ D_delete_package;
   subr_ D_find_all_symbols;
   subr_ D_map_symbols;
@@ -959,7 +959,6 @@ extern struct subr_tab_ {
   subr_ D_simple_vector_p;
   subr_ D_simple_string_p;
   subr_ D_simple_bit_vector_p;
-  subr_ D_commonp;
   subr_ D_type_of;
   subr_ D_defclos;
   subr_ D_class_p;
@@ -1763,6 +1762,7 @@ extern struct symbol_tab_ {
   symbol_ S_unintern;
   symbol_ S_export;
   symbol_ S_unexport;
+  symbol_ S_reexport;
   symbol_ S_import;
   symbol_ S_shadowing_import;
   symbol_ S_shadow;
@@ -1770,7 +1770,6 @@ extern struct symbol_tab_ {
   symbol_ S_unuse_package;
   symbol_ S_make_package;
   symbol_ S_pin_package;
-  symbol_ S_in_package;
   symbol_ S_delete_package;
   symbol_ S_find_all_symbols;
   symbol_ S_map_symbols;
@@ -1864,7 +1863,6 @@ extern struct symbol_tab_ {
   symbol_ S_simple_vector_p;
   symbol_ S_simple_string_p;
   symbol_ S_simple_bit_vector_p;
-  symbol_ S_commonp;
   symbol_ S_type_of;
   symbol_ S_defclos;
   symbol_ S_class_p;
@@ -2004,9 +2002,6 @@ extern struct symbol_tab_ {
   symbol_ S_make_buffered_input_stream;
   symbol_ S_buffered_input_stream_index;
   symbol_ S_make_buffered_output_stream;
-  symbol_ S_generic_stream_controller;
-  symbol_ S_make_generic_stream;
-  symbol_ S_generic_stream_p;
   symbol_ S_make_keyboard_stream;
   symbol_ S_terminal_raw;
   symbol_ S_make_window;
@@ -2391,6 +2386,9 @@ extern struct symbol_tab_ {
   symbol_ S_stream_force_output;
   symbol_ S_stream_clear_output;
   symbol_ S_stream_line_column;
+  symbol_ S_generic_stream_controller;
+  symbol_ S_make_generic_stream;
+  symbol_ S_generic_stream_p;
   symbol_ S_generic_stream_rdch;
   symbol_ S_generic_stream_pkch;
   symbol_ S_generic_stream_read_char_will_hang_p;
@@ -2608,6 +2606,7 @@ extern struct symbol_tab_ {
   symbol_ S_traced_definition;
   symbol_ S_gensym_counter;
   symbol_ S_pprint_first_newline;
+  symbol_ S_print_symbols_long;
   symbol_ S_inhibit_floating_point_underflow;
   symbol_ S_warn_on_floating_point_contagion;
   symbol_ S_floating_point_contagion_ansi;
