@@ -1,7 +1,11 @@
 ;;;; Debugger, Stepper, Errors
 
-(in-package "LISP")
-(export '(*prompt*))
+(in-package "EXT")
+(export '(custom::*prompt*) "CUSTOM")
+(export
+ '(*command-index* prompt-new-package package-short-name
+   custom::*prompt*)
+ "EXT")
 (in-package "SYSTEM")
 
 ;;;--------------------------------------------------------------------------
@@ -68,7 +72,7 @@ If anything else, printed.")
 (defun prompt-string2 ()
   (princ-to-string
     (if (functionp *prompt*)
-      (lisp::ignore-errors (funcall *prompt*))
+      (ignore-errors (funcall *prompt*))
       *prompt*)))
 ;; Prompt: last part
 (defun prompt-string3 () "> ")
@@ -208,8 +212,9 @@ If anything else, printed.")
 (defun commands0 ()
   (list
    (ENGLISH "
-Help (abbrev :h) this list Use the usual editing capabilities.(quit)
-or (exit) leaves CLISP.")
+Help (abbreviated :h) = this list
+Use the usual editing capabilities.
+(quit) or (exit) leaves CLISP.")
 
    (cons "Help"         #'debug-help)
    (cons ":h"           #'debug-help)))
